![logo](https://github.com/alexzanderr/_core-dev/blob/main/static/img/logo/_core-logo-dev-readme.png?raw=True)

<p align="center">
    <a href="https://choosealicense.com/licenses/mit/" alt="License: MIT">
        <img src="https://img.shields.io/badge/license-MIT-green.svg" />
    </a>
    <a href="https://choosealicense.com/licenses/mit/" alt="License: MIT">
        <img src="https://github.com/alexzanderr/_core-dev/blob/main/static/img/coverage/coverage.svg?raw=True">
    </a>
    <a href="https://choosealicense.com/licenses/mit/" alt="License: MIT">
        <img src="https://github.com/alexzanderr/_core-dev/blob/main/static/img/coverage/docs.svg?raw=True">
    </a>
</p>

these are not from me, but they are inspiration for better readme
<p align="center">
    <img src="https://github.com/HunterMcGushion/docstr_coverage/workflows/Python%20package/badge.svg" />
    <a href='https://docstr-coverage.readthedocs.io/en/latest/?badge=latest'>
        <img src='https://readthedocs.org/projects/docstr-coverage/badge/?version=latest' alt='Documentation Status' />
    </a>
    <a href="https://pypi.org/project/docstr-coverage/">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/docstr-coverage">
    </a>
    <a href="https://img.shields.io/pypi/pyversions/docstr-coverage">
        <img alt="Python Version" src="https://img.shields.io/pypi/pyversions/docstr-coverage">
    </a>
    <a href="https://pepy.tech/project/docstr-coverage">
        <img alt="Download count" src="https://static.pepy.tech/personalized-badge/docstr-coverage?period=total&units=international_system&left_color=gray&right_color=orange&left_text=downloads">
    </a>
    <a href="https://black.readthedocs.io/en/stable/" alt="Code Style: Black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" />
    </a>
</p>

# the `_core` package
this is the dev branch (experimental only)

best of the best - meaning: you got all python utilities ever in one package



# TODO
check [`TODO.md`](https://github.com/alexzanderr/_core-dev/blob/main/TODO.md)


### why there is a test_core outside the package

because we simulate how it would be to import `_core` from other python packages

assuming that `_core` is in PYTHONPATH
